#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "f118-A.csm"
print ('\n==> Loading geometry from file "'+filename+'"...')
myProblem = pyCAPS.Problem(problemName = "workDir_3_Save",
                           capsFile = filename)

# Create an alias to geometry
f118 = myProblem.geometry

# geometry.despmtr is a Sequence of ValueIn Objects of all DESPMTR defined in the csm file
# Set wide fuselage "fuse:width"
f118.despmtr["fuse:width"].value = 60

# Double the htail:area
htail_area = f118.despmtr["htail:area"].value
f118.despmtr["htail:area"].value = htail_area*2

print ("--> old htail:area = ", htail_area)
print ("--> new htail:area = ", f118.despmtr["htail:area"].value)

# Double the vtail area in an array
vtail = f118.despmtr["vtail"].value
vtail[0] *= 2
f118.despmtr["vtail"].value = vtail

# Build and save geometry
print ('\n==> Bulding and saving geometry...')
f118.save("f118_3_Save_Wide.egads")


# Build the Canard variant

# Reset the fuselage
f118.despmtr["fuse:width"].value = 20

htail_area = f118.despmtr["htail:area"].value
wing_area  = f118.despmtr["wing:area"].value

# Swap "wing:area" and "htail:area"
f118.despmtr["htail:area"].value = wing_area
f118.despmtr["wing:area"].value  = htail_area/2

# Rebuild and save geometry
print ('\n==> Bulding and saving geometry...')
f118.save("f118_3_Save_Canard.egads")
