#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "f118-A.csm"
print ('\n==> Loading geometry from file "'+filename+'"...')
myProblem = pyCAPS.Problem(problemName = "workDir_4_writeParameters_1",
                           capsFile = filename)

# Create an alias to geometry
f118 = myProblem.geometry

# geometry.despmtr is a Sequence of ValueIn Objects of all DESPMTR defined in the csm file
# Set wide fuselage "fuse:width"
f118.despmtr["fuse:width"].value = 60

# Double the htail:area
htail_area = f118.despmtr["htail:area"].value
f118.despmtr["htail:area"].value = htail_area*2

# Double the vtail area in an array
vtail = f118.despmtr["vtail"].value
vtail[0] *= 2
f118.despmtr["vtail"].value = vtail

# Write geometry parameters
paramFile = "f118_4.params"
print ('\n==> Saving parameters to "'+paramFile+'"...')
f118.writeParameters(paramFile)

print ('\n==> Loading 2nd geometry from file "'+filename+'"...')
myProblem2 = pyCAPS.Problem(problemName = "workDir_4_writeParameters_2",
                           capsFile = filename,
                           outLevel = 0)

# Read back in the parmeters
print ('\n==> Reading parameters from "'+paramFile+'"...')
myProblem2.geometry.readParameters(paramFile)

# View the geomtry
print ('\n==> Building and viewing the geometry...')
myProblem2.geometry.view()
