#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "f118-A.csm"
print ('\n==> Loading geometry from file "'+filename+'"...')
myProblem = pyCAPS.Problem(problemName = "workDir_6_Shortcut",
                           capsFile = filename)

# Create an alias to geometry
f118 = myProblem.geometry

# Double the "vtail" area in an array
vtail = f118.despmtr.vtail
vtail[0] *= 2
f118.despmtr.vtail = vtail

# Set wide fuselage "fuse:width" via shortcuts
f118.despmtr["fuse:width"].value = 60
f118.despmtr.fuse.width = 60
f118.despmtr["fuse"].width = 60
f118.despmtr["fuse"]["width"].value = 60

# Double the "htail:area"
htail_area = f118.despmtr["htail"].area
f118.despmtr["htail"].area = htail_area*2

print ("--> old htail:area = ", htail_area)
print ("--> new htail:area = ", f118.despmtr["htail:area"].value)

# Build and view the geometry with ESP
print ('\n==> Bulding and viewing geometry...')
f118.view()


# Build the Canard variant

# Reset the fuselage "fuse:width"
f118.despmtr["fuse"].width = 20

htail_area = f118.despmtr["htail"]["area"].value
wing_area  = f118.despmtr.wing.area

# Swap "wing:area" and "htail:area"
f118.despmtr["htail"]["area"].value = wing_area
f118.despmtr.wing.area              = htail_area/2

# Rebuild and view geometry
print ('\n==> Bulding and viewing geometry...')
f118.view()

# Display grouped design parameters
print ('\n==> Grouped parameters')
for group in ["fuse", "wing", "htail"]:
    print ('-->', group)
    for key in f118.despmtr[group].keys():
        print ('    {:<12}'.format(group+":"+key), 
               '=', f118.despmtr[group][key].value)

