#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "f118-C.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
myProblem = pyCAPS.Problem(problemName = "workDir_6_f118_Wing",
                           capsFile = filename,
                           outLevel = 0)

# Create a masstran aim with the wing
masstran = myProblem.analysis.create(aim = "masstranAIM", 
                                     name = "masstran",
                                     capsIntent="wing")

# Define material properties
unobtainium = {"density" : 7850}

# Set the material
masstran.input.Material = {"Unobtainium": unobtainium}

# Define shell property
shell = {"propertyType"      : "Shell",
         "material"          : "Unobtainium",
         "membraneThickness" : 0.2} 

# Associate the shell property with capsGroups defined on the geometry
masstran.input.Property = {"wing:faces": shell}

# run pre/post-analysis to execute masstran
masstran.preAnalysis()
masstran.postAnalysis()

# Extract the mass and CG for the wing
Mass = masstran.output.Mass
CG   = masstran.output.CG

print()
print("--> Mass =", Mass)
print("--> CG   =", CG)
