#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "naca.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
myProblem = pyCAPS.Problem(problemName = "workDir_2_Analysis",
                           capsFile = filename,
                           outLevel = 1)

# Create xfoil aim
print ("\n==> Creating xfoilAIM")
xfoil = myProblem.analysis.create(aim = "xfoilAIM",
                                  name = "xfoil")

print ("\n==> Setting analysis values")
# Set Mach and Reynolds number
xfoil.input.Mach = 0.5
xfoil.input.Re   = 1.0e6

# Set list of Alpha
xfoil.input.Alpha = [0.0, 3.0, 5.0, 7.0, 8.0]


# Run AIM pre-analysis
print ("\n==> Running preAnalysis")
xfoil.preAnalysis()

####### Run xfoil ####################
print ("\n\n==> Running xFoil......")

currentDirectory = os.getcwd() # Get current working directory
os.chdir(xfoil.analysisDir)    # Move into analysis directory

# Run xfoil via system call
os.system("xfoil < xfoilInput.txt > Info.out"); 

os.chdir(currentDirectory)     # Move back to top directory
######################################

# Run AIM post-analysis
print ("\n==> Running postAnalysis")
xfoil.postAnalysis()


# Retrieve Alpha, Cl and Cd
print ("\n==> Retrieve analysis results")
Alpha = xfoil.output.Alpha
Cl    = xfoil.output.CL
Cd    = xfoil.output.CD

print()
print("--> Alpha =", Alpha)
print("--> Cl    =", Cl)
print("--> Cd    =", Cd)
print()
