#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","EGADS","CFDInviscid_Wing.egads")
myProblem = pyCAPS.Problem(problemName = "workDir_03_MeshLength",
                           capsFile = filename,
                           outLevel = 1)

# Create AFLR4 AIM
aflr4 = myProblem.analysis.create(aim = "aflr4AIM",
                                  name = "aflr4")

# Mark capsMesh == Farfield with a Farfield bcType
aflr4.input.Mesh_Sizing = {"Farfield": {"bcType":"Farfield"}}

# Farfield growth factor
aflr4.input.ff_cdfr = 1.4

# Scaling factor to compute AFLR4 'ref_len' parameter via
# ref_len = capsMeshLength * Mesh_Length_Factor
aflr4.input.Mesh_Length_Factor = 5

# Relative scale of maximum spacing bound relative to ref_len
# max_spacing = max_scale * ref_len
aflr4.input.max_scale = 0.1

# Relative scale of minimum spacing bound relative to ref_len
# min_spacing = min_scale * ref_len
aflr4.input.min_scale = 0.01

# Absolute scale of minimum spacing bound for proximity
# abs_min_spacing = abs_min_scale * ref_len
aflr4.input.abs_min_scale = 0.001

# Use mesh length factor to make a series of meshes (not a family)
for Length_Factor in [1, 3, 9]:
    aflr4.input.Mesh_Length_Factor = Length_Factor

    # Run AIM pre-/post-analysis
    aflr4.preAnalysis()
    aflr4.postAnalysis()

    # View the surface tessellation
    aflr4.geometry.view()
