#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","EGADS","CFDInviscid_Wing.egads")
myProblem = pyCAPS.Problem(problemName = "workDir_09_InvsicidWing",
                           capsFile = filename,
                           outLevel = 1)

# Create AFLR4 AIM
aflr4 = myProblem.analysis.create(aim = "aflr4AIM",
                                  name = "aflr4")

# Dump VTK files for visualization
aflr4.input.Proj_Name = "TransportWing"
aflr4.input.Mesh_Format = "VTK"

# Farfield growth factor
aflr4.input.ff_cdfr = 1.4

# Scaling factor to compute AFLR4 'ref_len' parameter via
# ref_len = capsMeshLength * Mesh_Length_Factor
aflr4.input.Mesh_Length_Factor = 5

# Edge mesh spacing discontinuity scaled interpolant and farfield BC
aflr4.input.Mesh_Sizing = {"riteWing": {"edgeWeight":1.0},
                           "leftWing": {"edgeWeight":1.0},
                           "Farfield": {"bcType":"Farfield"}}

# Run AIM pre-/post-analysis
aflr4.preAnalysis()
aflr4.postAnalysis()

# View the surface tessellation
#aflr4.geometry.view()

#------------------------------------------------------------------------------#

# Create AFLR3 AIM to generate the volume mesh
aflr3 = myProblem.analysis.create(aim  = "aflr3AIM",
                                  name = "aflr3")

# Link the aflr4 Surface_Mesh as input to aflr3
aflr3.input["Surface_Mesh"].link(aflr4.output["Surface_Mesh"])

# Dump VTK files for visualization
aflr3.input.Proj_Name   = "TransportWing"
aflr3.input.Mesh_Format = "VTK"

# Run AIM pre-/post-analysis
aflr3.preAnalysis()
aflr3.postAnalysis()
