#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os and platform
import os
import platform
import time

#------------------------------------------------------------------------------#

def run_pointwise(pointwise):
    # Run AIM pre-analysis
    pointwise.preAnalysis()

    ####### Run pointwise #################
    currentDirectory = os.getcwd() # Get current working directory
    os.chdir(pointwise.analysisDir)    # Move into test directory

    CAPS_GLYPH = os.environ["CAPS_GLYPH"]
    for i in range(60):
        if "Windows" in platform.system():
            PW_HOME = os.environ["PW_HOME"]
            os.system('"' + PW_HOME + '\\win64\\bin\\tclsh.exe ' + CAPS_GLYPH + '\\GeomToMesh.glf" caps.egads capsUserDefaults.glf')
        else:
            os.system("pointwise -b " + CAPS_GLYPH + "/GeomToMesh.glf caps.egads capsUserDefaults.glf")

        time.sleep(1) # let the harddrive breathe
        if os.path.isfile('caps.GeomToMesh.gma') and os.path.isfile('caps.GeomToMesh.ugrid'): break
        time.sleep(20) # wait and try again

    os.chdir(currentDirectory)     # Move back to top directory
    #######################################

    # Run AIM post-analysis
    pointwise.postAnalysis()

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","EGADS","CFDViscous_Transport.egads")
myProblem = pyCAPS.Problem(problemName = "workDir_10_ViscousTransport",
                           capsFile = filename,
                           outLevel = 1)

# Create pointwise aim
pointwise = myProblem.analysis.create(aim = "pointwiseAIM",
                                      name = "pointwise")

# Dump VTK files for visualization
pointwise.input.Proj_Name   = "Transport"
pointwise.input.Mesh_Format = "VTK"

# Connector level
pointwise.input.Connector_Turn_Angle       = 10
pointwise.input.Connector_Prox_Growth_Rate = 1.2
pointwise.input.Connector_Source_Spacing   = True

# Domain level
pointwise.input.Domain_Algorithm    = "AdvancingFront"
pointwise.input.Domain_Max_Layers   = 15
pointwise.input.Domain_Growth_Rate  = 1.2
pointwise.input.Domain_TRex_ARLimit = 40.0
pointwise.input.Domain_Decay        = 0.8
pointwise.input.Domain_Structure_AR_Convert = 10.0

# Block level
pointwise.input.Block_Boundary_Decay       = 0.8
pointwise.input.Block_Collision_Buffer     = 1.0
pointwise.input.Block_Max_Skew_Angle       = 160.0
pointwise.input.Block_Edge_Max_Growth_Rate = 1.5
pointwise.input.Block_Full_Layers          = 1
pointwise.input.Block_Max_Layers           = 100
pointwise.input.Block_TRex_Skew_Delay      = 1

# Set wall spacing for capsMesh attributes
airplaneWall = {"boundaryLayerSpacing" : 0.01}
controlWall  = {"boundaryLayerSpacing" : 0.005}
pointwise.input.Mesh_Sizing = {"leftWing": airplaneWall,
                               "riteWing": airplaneWall,
                               "Htail"   : airplaneWall,
                               "Vtail"   : airplaneWall,
                               "Fuselage": airplaneWall,
                               "Pylon"   : airplaneWall,
                               "Pod"     : airplaneWall,
                               "Control" : controlWall}

# Execute pointwise
run_pointwise(pointwise)

# View the surface tessellation
#pointwise.geometry.view()
