#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = os.path.join("..","ESP","wing3.csm")
print ("\n==> Loading geometry from file \""+filename+"\"...")
myProblem = pyCAPS.Problem(problemName = "workDir_3_Params",
                           capsFile = filename,
                           outLevel = 1)

# Alias the geometry
wing = myProblem.geometry

# Set geometry variables for structural IML/OML
wing.cfgpmtr.VIEW.Concept          = 0
wing.cfgpmtr.VIEW.ClampedStructure = 1
wing.cfgpmtr.VIEW.BoxStructure     = 0

# Create EGADS Tess aim
tess = myProblem.analysis.create(aim = "egadsTessAIM",
                                 name = "tess")

# Dissable TFI and Templates that generate "structured" triangular meshes
tess.input.TFI_Templates = False

maxLength = 0.10 # bound on maximum segment length (0 - any length)
deviation = 0.01 # deviation from triangle centroid to geometry
dihedral  = 15   # maximum interior dihedral angle between triangle facets

# Set EGADS body tessellation parameters
tess.input.Tess_Params = [maxLength, deviation, dihedral]

# Impact of changing bound on the maximum segment
for maxLength in [0, 0.3, 0.1]:
    tess.input.Tess_Params = [maxLength, 0.1, 30]

    # Run AIM pre/post-analysis
    tess.preAnalysis()
    tess.postAnalysis()

    # View the tessellation
    tess.geometry.view()

