#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = os.path.join("..","ESP","wing3.csm")
print ("\n==> Loading geometry from file \""+filename+"\"...")
myProblem = pyCAPS.Problem(problemName = "workDir_6_TriQuad",
                           capsFile = filename,
                           outLevel = 1)

# Alias the geometry
wing = myProblem.geometry

# Set geometry variables for structure with complete OML
wing.cfgpmtr.VIEW.Concept          = 0
wing.cfgpmtr.VIEW.ClampedStructure = 1
wing.cfgpmtr.VIEW.BoxStructure     = 0

# Create EGADS Tess aim
tess = myProblem.analysis.create(aim = "egadsTessAIM",
                                 name = "tess")

# Set EGADS body tessellation parameters
tess.input.Tess_Params = [0.1, 0.01, 20]

#------------------------------------------------------------------------------#

# Triangle tessellation
tess.input.Mesh_Elements = "Tri"

# Run AIM pre/post-analysis
tess.preAnalysis()
tess.postAnalysis()

# View the tessellation
tess.geometry.view()

#------------------------------------------------------------------------------#

# Regularized quad tessellation
tess.input.Mesh_Elements = "Quad"

# Run AIM pre/post-analysis
tess.preAnalysis()
tess.postAnalysis()

# View the tessellation
tess.geometry.view()

#------------------------------------------------------------------------------#

# Set geometry variables for structure with wing-box
wing.cfgpmtr.VIEW.Concept          = 0
wing.cfgpmtr.VIEW.ClampedStructure = 1
wing.cfgpmtr.VIEW.BoxStructure     = 1

# Triangle tessellation
tess.input.Mesh_Elements = "Tri"

# Run AIM pre/post-analysis
tess.preAnalysis()
tess.postAnalysis()

# View the tessellation
tess.geometry.view()

#------------------------------------------------------------------------------#

# Regularized quad tessellation
tess.input.Mesh_Elements = "Quad"

# Run AIM pre/post-analysis
tess.preAnalysis()
tess.postAnalysis()

# View the tessellation
tess.geometry.view()

#------------------------------------------------------------------------------#

