#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

def run_xfoil(xfoil):
    # Run AIM pre-analysis
    print ("\n==> Running preAnalysis")
    xfoil.preAnalysis()

    ####### Run xfoil ####################
    print ("\n\n==> Running xFoil......")

    currentDirectory = os.getcwd() # Get current working directory
    os.chdir(xfoil.analysisDir)    # Move into test directory

    # Run xfoil via system call
    os.system("xfoil < xfoilInput.txt > Info.out");

    os.chdir(currentDirectory)     # Move back to top directory
    ######################################

    # Run AIM post-analysis
    print ("\n==> Running postAnalysis")
    xfoil.postAnalysis()

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = os.path.join("..","..","data","session03","naca.csm")
print ("\n==> Loading geometry from file \""+filename+"\"...")
myProblem = pyCAPS.Problem(problemName = "workDir_xfoilThick",
                           capsFile = filename,
                           outLevel = 0)

# Alias the geometry
naca = myProblem.geometry

# Create xfoil aim
print ("\n==> Create xfoilAIM")
xfoil = myProblem.analysis.create(aim = "xfoilAIM",
                                  name = "xfoil")

print ("\n==> Setting analysis values")
# Set Mach and Reynolds number
xfoil.input.Mach = 0.5
xfoil.input.Re   = 1.0e6

# Set list of Alpha
xfoil.input.Alpha = [0.0, 1.0, 3.0]

# List of thicknesses to analyze
Thickness = [0.08, 0.10, 0.12, 0.16]

Alpha = []; Cl = []; Cd = []
for thick in Thickness:
    # Modify the thickness
    naca.despmtr.thick = thick

    # Run xfoil
    run_xfoil(xfoil)

    # Append Alpha, Cl and Cd
    print ("\n==> Retrieve analysis results")
    Alpha.append(xfoil.output.Alpha)
    Cl.append(xfoil.output.CL)
    Cd.append(xfoil.output.CD)

print()
print("--> Thickness =", Thickness)
print("--> Alpha     =", Alpha)
print("--> Cl        =", Cl)
print("--> Cd        =", Cd)
print()
