#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","..","data","EGADS","CFDInviscid_Transport.egads")
myProblem = pyCAPS.Problem(problemName = "workDir_InviscidTransport_150k",
                           capsFile = filename,
                           outLevel = 1)

# Create AFLR4 AIM
aflr4 = myProblem.analysis.create(aim = "aflr4AIM",
                                  name = "aflr4")

# Scaling factor to compute AFLR4 'ref_len' parameter via
# ref_len = capsMeshLength * Mesh_Length_Factor
aflr4.input.Mesh_Length_Factor = 2

# The spacing is derived from the curvature factor divided
# by the curvature.
# Curvature = 1 / Curvature_Radius
# Spacing = curv_factor / Curvature
aflr4.input.curv_factor = 0.2

# Scale components
aflr4.input.Mesh_Sizing = {"Farfield": {"bcType":"Farfield"},
                           "Fuselage": {"scaleFactor":1},
                           "leftWing": {"scaleFactor":2, "edgeWeight":0.0},
                           "riteWing": {"scaleFactor":2, "edgeWeight":0.0},
                           "Htail"   : {"scaleFactor":2, "edgeWeight":0.0},
                           "Vtail"   : {"scaleFactor":2, "edgeWeight":0.0},
                           "Pod"     : {"scaleFactor":1}}

# Farfield growth factor
aflr4.input.ff_cdfr = 1.4

# Run AIM pre-/post-analysis
aflr4.preAnalysis()
aflr4.postAnalysis()

# View the surface tessellation
aflr4.geometry.view()

# Print the total element count
print("--> Toal Elements", aflr4.output.NumberOfElement)
