#------------------------------------------------------------------------------#
#
# Note:
# This script assumes that
#
# ATTRIBUTE PW:DomainAdaptSource  $true
# ATTRIBUTE PW:DomainAdaptTrarget $true
#
# Have been added to the Wing and/or Pod to enable domain-to-domain proximity detection
#
#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os and platform
import os
import platform
import time

#------------------------------------------------------------------------------#

def run_pointwise(pointwise):
    # Run AIM pre-analysis
    pointwise.preAnalysis()

    ####### Run pointwise #################
    currentDirectory = os.getcwd() # Get current working directory
    os.chdir(pointwise.analysisDir)    # Move into test directory

    CAPS_GLYPH = os.environ["CAPS_GLYPH"]
    for i in range(60):
        if "Windows" in platform.system():
            PW_HOME = os.environ["PW_HOME"]
            os.system('"' + PW_HOME + '\\win64\\bin\\tclsh.exe ' + CAPS_GLYPH + '\\GeomToMesh.glf" caps.egads capsUserDefaults.glf')
        else:
            os.system("pointwise -b " + CAPS_GLYPH + "/GeomToMesh.glf caps.egads capsUserDefaults.glf")

        time.sleep(1) # let the harddrive breathe
        if os.path.isfile('caps.GeomToMesh.gma') and os.path.isfile('caps.GeomToMesh.ugrid'): break
        time.sleep(20) # wait and try again

    os.chdir(currentDirectory)     # Move back to top directory
    #######################################

    # Run AIM post-analysis
    pointwise.postAnalysis()

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","..","data","ESP","transport.csm")
myProblem = pyCAPS.Problem(problemName = "workDir_DomainProximity",
                           capsFile = filename,
                           outLevel = 1)

# Alias the geometry
transport = myProblem.geometry

# Change to Inviscid CFD view
transport.cfgpmtr.VIEW.Concept     = 0
transport.cfgpmtr.VIEW.CFDInviscid = 1
transport.cfgpmtr.VIEW.CFDViscous  = 0

# Enable wing+pod
transport.cfgpmtr.COMP.Wing    = 1
transport.cfgpmtr.COMP.Fuse    = 0
transport.cfgpmtr.COMP.Htail   = 0
transport.cfgpmtr.COMP.Vtail   = 0
transport.cfgpmtr.COMP.Pod     = 1
transport.cfgpmtr.COMP.Control = 0

# Create pointwise aim
pointwise = myProblem.analysis.create(aim = "pointwiseAIM",
                                      name = "pointwise")

# Dump VTK files for visualization
pointwise.input.Proj_Name   = "TransportWingPod"
pointwise.input.Mesh_Format = "VTK"

# Connector level
#pointwise.input.Connector_Turn_Angle    = 10
pointwise.input.Connector_Source_Spacing = True

# Domain level
#pointwise.input.Domain_Algorithm     = "AdvancingFront"
#pointwise.input.Domain_Max_Layers    = 15
#pointwise.input.Domain_TRex_ARLimit  = 20.0
#pointwise.input.Domain_Decay         = 0.8

# Block level
pointwise.input.Block_Boundary_Decay       = 0.8
pointwise.input.Block_Edge_Max_Growth_Rate = 1.5

# Demonstrate the impact of Connector_Source_Spacing
for domAdapt in [False, True]:
    # Modify the source spacing
    pointwise.input.Domain_Adapt = domAdapt

    # Change the project name so files are not overwritten
    pointwise.input.Proj_Name = "TransportWingPod_domAdapt_" + str(domAdapt)

    # Execute pointwise
    run_pointwise(pointwise)

    # View the surface tessellation
    pointwise.geometry.view()
