#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = os.path.join("..","..","data","ESP","wing3.csm")
print ("\n==> Loading geometry from file \""+filename+"\"...")
myProblem = pyCAPS.Problem(problemName = "workDir_2k",
                           capsFile = filename,
                           outLevel = 1)

# Alias the geometry
wing = myProblem.geometry

# Set geometry variables for structure with box spar
wing.cfgpmtr.VIEW.Concept          = 0
wing.cfgpmtr.VIEW.ClampedStructure = 1
wing.cfgpmtr.VIEW.BoxStructure     = 1

# Create EGADS Tess aim
tess = myProblem.analysis.create(aim = "egadsTessAIM",
                                 name = "tess")

# Set EGADS body tessellation parameters
tess.input.Tess_Params = [1.0, 1.0, 20]

# Modify local mesh sizing parameters
Mesh_Sizing = {"leadingEdge"    : {"numEdgePoints" : 4},
               "rootLeadingEdge": {"numEdgePoints" : 9}}

tess.input.Mesh_Sizing = Mesh_Sizing

#------------------------------------------------------------------------------#

# Triangle tessellation
tess.input.Mesh_Elements = "Quad"

# Run AIM pre/post-analysis
tess.preAnalysis()
tess.postAnalysis()

# View the tessellation
tess.geometry.view()

#------------------------------------------------------------------------------#

# Print the total element count
print("--> Total Elements", tess.output.NumberOfElement)

